@@ -27,7 +27,7 @@ our $opt_namespace;
 
 use Getopt::Euclid qw( :vars<opt_> );
 use List::MoreUtils qw{firstidx} ;
-use version ; our $VERSION = qv('1.3.2');
+use version ; our $VERSION = qv('1.3.3');
 use Data::Dumper;
 use File::Basename;
 use Smart::Comments;
@@ -62,6 +62,10 @@ my $classname       = undef ;
 $classname          = $opt_classname    if     defined $opt_classname ;
 $classname          = $outpfx           unless defined $classname ;
 
+my $namespace       = undef ; 
+$namespace          = $opt_namespace    if     defined $opt_namespace ;
+$namespace          = $outpfx           unless defined $namespace ;
+
 
 croak 'Invalid output file' unless exists $ValidParserMakeArgs{$outsfx} ;
 my $outResxFile = "${outpfx}.resx" ;
@@ -226,7 +230,7 @@ croak "Duplicate Test names exist:- @dupTestNames, Tests cannot be merged."
 croak "Duplicate Condition names exist: @dupConditionNames, Tests cannot be merged."
     if scalar @dupConditionNames ;
 }
-my $mergedTestSet = VSGDR::UnitTest::TestSet->new( { NAMESPACE        => $opt_namespace
+my $mergedTestSet = VSGDR::UnitTest::TestSet->new( { NAMESPACE        => $namespace
                                                     , CLASSNAME        => $classname
                                                     }
                                                   ) ;
@@ -279,7 +283,7 @@ mergeGDRTests.pl - Merge multiple GDR test files into one combined file.
 
 =head1 VERSION
 
-1.3.1
+1.3.3
 
 =head1 USAGE
 
@@ -306,19 +310,11 @@ Specify output file
     file.type:    writable
 
 
-=item  -n[ame][space] [=]<namespace>
-
-Specify namespace for test class
-
-=for Euclid:
-    namespace.type:    string
-
 
 
 =back
 
 
-
 =head1 OPTIONS
 
 =over
@@ -338,6 +334,14 @@ Output version type
     outputversion.type:    /[12]/
     outputversion.default:  2
 
+=item  -n[ame][space] [=]<namespace>
+
+Specify namespace for test class
+
+=for Euclid:
+    namespace.type:    string
+    
+
 
 
 =back
